# -*- coding: utf-8 -*-

from django.conf import settings
from jssor.models import Slideshow, Slide
try:
    import xadmin

    class SlideXadmin(object):
        if 'reversion' in settings.INSTALLED_APPS:
            reversion_enable = True
        show_bookmarks = False
        list_display = ['title','image','slideshow']
    
    
    class SlideshowXadmin(object):
        if 'reversion' in settings.INSTALLED_APPS:
            reversion_enable = True
        show_bookmarks = False
        relfield_style = 'fk-ajax'
    
    
    xadmin.site.register(Slide, SlideXadmin)
    xadmin.site.register(Slideshow, SlideshowXadmin)
except:
    pass


# -*- coding: utf-8 -*-

from django.db import models
from django.conf import settings
from django.utils.translation import ugettext_lazy as _


if hasattr(settings, 'SLIDESHOW_TYPES'):
    SLIDESHOW_TYPES = settings.SLIDESHOW_TYPES
else:
    SLIDESHOW_TYPES = (
                   ('jssor/full_width_slider.html',_(u'Full width slider')),
                   ('jssor/thumbnails_navigator_with_arrows.html',_(u'Thumbnails navigator with arrows')),
                   ('jssor/banner_slider.html',_(u'Banner slider')),
                   ('jssor/bootstrap_slider.html',_(u'Bootstrap slider')),
                   )
    

class Slideshow(models.Model):
    title = models.CharField(max_length=250, null=True, verbose_name=_(u'Title'))
    slug = models.SlugField(max_length=150, unique=True, default='', verbose_name=_(u'Id'), help_text=_(u"This field must not contain any spaces, special characters or capital letter"))
    template_name = models.CharField(max_length=150, null=True, choices=SLIDESHOW_TYPES, default=SLIDESHOW_TYPES[0][0], verbose_name=_(u'Slideshow type'))
    autoplay = models.BooleanField(default=False, verbose_name=_(u'Autoplay'))
    width = models.PositiveSmallIntegerField(null=True, blank=True, verbose_name=_(u'Width'))
    height = models.PositiveSmallIntegerField(null=True, blank=True, verbose_name=_(u'Height'))

    class Meta:
        verbose_name = _(u'Slideshow')
        verbose_name_plural = _(u'Slideshows')

    def __unicode__(self):
        return unicode(self.title)
    
    
class Slide(models.Model):
    title = models.CharField(max_length=250, null=True, verbose_name=_(u'Title'))
    image = models.ImageField(upload_to='jssor', blank=False, null=True, verbose_name=_(u'Image'))
    thumbnail = models.ImageField(upload_to='jssor/thumbnails', blank=True, null=True, verbose_name=_(u'Thumbnail'))
    slideshow = models.ForeignKey(Slideshow, null=True, on_delete=models.SET_NULL, verbose_name=_(u'Slideshow'))
    order = models.PositiveSmallIntegerField(null=True, verbose_name=_(u'Order'))
    link = models.CharField(null=True, blank=True, max_length=255, verbose_name=_(u'Link'))
    link_is_blank = models.BooleanField(default=False, verbose_name=_(u'Open link in a new tab'))
    
    class Meta:
        ordering = ('order',)
        verbose_name=_(u'Slide')
        verbose_name_plural = _(u'Slides')

    def __unicode__(self):
        if self.slideshow:
            return unicode(self.title)+' ( '+self.slideshow.title+' )'
        else:
            return unicode(self.title)+_(u' ( No slideshow )')
    
    
    


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Slide',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('title', models.CharField(max_length=250, null=True, verbose_name='Title')),
                ('image', models.ImageField(upload_to=b'jssor', null=True, verbose_name='Image')),
                ('thumbnail', models.ImageField(upload_to=b'jssor/thumbnails', null=True, verbose_name='Thumbnail', blank=True)),
                ('order', models.PositiveSmallIntegerField(null=True, verbose_name='Order')),
                ('link', models.CharField(max_length=255, null=True, verbose_name='Link', blank=True)),
                ('link_is_blank', models.BooleanField(default=False, verbose_name='Open link in a new tab')),
            ],
            options={
                'ordering': ('order',),
                'verbose_name': 'Slide',
                'verbose_name_plural': 'Slides',
            },
        ),
        migrations.CreateModel(
            name='Slideshow',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('title', models.CharField(max_length=250, null=True, verbose_name='Title')),
                ('slug', models.SlugField(default=b'', max_length=150, help_text='This field must not contain any spaces, special characters or capital letter', unique=True, verbose_name='Id')),
                ('template_name', models.CharField(default=b'jssor/full_width_slider.html', max_length=150, null=True, verbose_name='Slideshow type', choices=[(b'jssor/full_width_slider.html', 'Full width slider'), (b'jssor/thumbnails_navigator_with_arrows.html', 'Thumbnails navigator with arrows'), (b'jssor/banner_slider.html', 'Banner slider'), (b'jssor/bootstrap_slider.html', 'Bootstrap slider')])),
                ('autoplay', models.BooleanField(default=False, verbose_name='Autoplay')),
                ('width', models.PositiveSmallIntegerField(null=True, verbose_name='Width', blank=True)),
                ('height', models.PositiveSmallIntegerField(null=True, verbose_name='Height', blank=True)),
            ],
            options={
                'verbose_name': 'Slideshow',
                'verbose_name_plural': 'Slideshows',
            },
        ),
        migrations.AddField(
            model_name='slide',
            name='slideshow',
            field=models.ForeignKey(on_delete=django.db.models.deletion.SET_NULL, verbose_name='Slideshow', to='jssor.Slideshow', null=True),
        ),
    ]



from setuptools import setup, find_packages

setup(
  name = 'django-jssor',
  packages=find_packages(),
  version = '0.2',
  description = 'Jssor slideshows for Django',
  author = 'synw',
  author_email = 'synwe@yahoo.com',
  url = 'https://github.com/synw/django-jssor', 
  download_url = 'https://github.com/synw/django-jssor/releases/tag/0.2', 
  keywords = ['django', 'slideshows', 'jssor'], 
  classifiers = [
        'Development Status :: 3 - Alpha',
        'Framework :: Django :: 1.8',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
    ],
  install_requires=[
        "Django >= 1.8.0",
        'Pillow'
    ],
  zip_safe=False
)
